diff --git a/asdf.asd b/asdf.asd
index fa151fa4e2d597393e85c497dd10a61340c2ec2d..a693ec342a6f108bd920255f798fbb571551f612 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.21.5" ;; to be automatically updated by bin/bump-revision
+  :version "2.22" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
diff --git a/debian/changelog b/debian/changelog
index af2f13d836c877cbc3c421441adc62350b104d2e..a98a2d583e781637a10a02e2ae2b1a3cf1e01e42 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,13 @@
+cl-asdf (2:2.22-1) unstable; urgency=low
+
+  * require is now mapped to the recently defined require-system,
+   not to load-system anymore.
+  * more sensible inheritance semantics for default-component-class,
+   which can be either a class or a class name.
+  * accept wildcards in directory-files for physical pathnames. lp#1000842
+
+ -- Francois-Rene Rideau <fare@tunes.org>  Tue, 12 Jun 2012 11:22:33 -0400
+
 cl-asdf (2:2.21-1) unstable; urgency=low
 
   * New features:
diff --git a/debian/control b/debian/control
index 69ba040f9c8b38aaa5bd44a3ee9de198559604c6..234f6070ae4520f4ae9a94d7100b41d504264007 100644
--- a/debian/control
+++ b/debian/control
@@ -7,7 +7,7 @@ Uploaders: Peter Van Eynde <pvaneynd@debian.org>,
   Francois-Rene Rideau <fare@tunes.org>
 Build-Depends: debhelper (>> 7)
 Build-Depends-Indep: texinfo, texlive-extra-utils, texlive, texlive-generic-recommended
-Standards-Version: 3.9.2
+Standards-Version: 3.9.3
 Homepage: http://common-lisp.net/project/asdf/
 Vcs-Git: git://common-lisp.net/projects/asdf/asdf.git
diff --git a/asdf.lisp b/asdf.lisp
index 99e7c489c32cefaa962433e8cffebd154384f484..5981f67fd8034716abe4842702ec306c7b89743d 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.21.5: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -116,7 +116,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.21.5")
+         (asdf-version "2.22")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.21.5: Another System Definition Facility.
+;;; This is ASDF 2.22: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: